# Sample PySys testcase
# Copyright (c) 2016-2017, 2020 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors. 
# Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG 

from pysys.constants import *
from pysys.basetest import BaseTest
from apama.correlator import CorrelatorHelper

class PySysTest(BaseTest):

	def execute(self):
		correlator = CorrelatorHelper(self, name='test-correlator')
		correlator.start(logfile=correlator.name+'.log', 
			config=[self.input+'/json-test-connectivity.yaml', self.project.appHome+'/json-codec.yaml'], 
			arguments=['-DTEST_INPUT_DIR=%s'%self.input])
		
		# since we expect errors do not use abortExpr in this test, but still 
		# pass in a process so that if the entire process failed we would immediately 
		# give up waiting
		self.waitForSignal(correlator.name+'.log', expr="UnitTestHarness output.*final message", 
			process=correlator.process)
		
	def validate(self):
		# check for no errors or test chain warnings we were not expecting
		self.assertGrep('test-correlator.log', expr='( ERROR .*| WARN .*MyTestChain.*)', contains=False, 
			ignores=[' WARN .*jsonCodec.MyTestChain> .*failed to transform message'])
			
		# check for the errors we were expected
		# no need to over-specify the error message - just check that the required info is present
		self.assertLineCount('test-correlator.log', 
			expr=' WARN .*jsonCodec.MyTestChain> .*failed to transform message.*aim.*payload=', 
			condition='==2')

		# check that valid messages can be parsed after failures
		self.assertGrep('test-correlator.log', 
			expr="UnitTestHarness output.*Safely handling empty payloads.*\{\}")

		# check that valid messages can be parsed after failures
		self.assertGrep('test-correlator.log', 
			expr="UnitTestHarness output.*final message.*Hello world")

		# two valid message should have been received
		self.assertLineCount('test-correlator.log', expr="UnitTestHarness output.*", condition='==2')
