# Sample PySys testcase
# Copyright (c) 2016, 2018, 2020 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors. 
# Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG 

import pysys
from pysys.constants import *

class PySysTest(pysys.basetest.BaseTest):

	def execute(self):
		# start the correlator using the init.yaml file for injections and event sending
		correlator = self.apama.startCorrelator('testCorrelator', config=[self.input+'/init.yaml'])

		# wait for all events to be processed
		self.waitForGrep('testCorrelator.log', expr="Received simple event with message", condition=">=2", 
			process=correlator.process, errorExpr=[' (ERROR|FATAL) .*'])
		
	def validate(self):
		# look for log statements in the correlator log file
		self.assertGrep('testCorrelator.log', expr=' (ERROR|FATAL) .*', contains=False)
		
		self.assertThat('events == expected', 
			events=self.getExprFromFile('testCorrelator.log', 'Received simple event with message - .*', returnAll=True),
			expected=[
				'Received simple event with message - This is the first simple event',
				'Received simple event with message - This is the second simple event',
			])

